local toc, data = ...
local AddonId = toc.identifier

-- Local config options ---------------------------------------------------------
local scale = 0.5
local healthOrbWidth = 256 * scale
local healthOrbHeight = 256 * scale
---------------------------------------------------------------------------------

-- Frame Configuration Options --------------------------------------------------
local HealthOrb = WT.UnitFrame:Template("CkauHealthOrb")
HealthOrb.Configuration.Name = "Health Orb / Орб Здоровья"
HealthOrb.Configuration.RaidSuitable = false
HealthOrb.Configuration.FrameType = "Frame"
HealthOrb.Configuration.Width = healthOrbWidth
HealthOrb.Configuration.Height = healthOrbHeight
---------------------------------------------------------------------------------


function HealthOrb:Construct(options)

	local template =
	{
		elements = 
		{
			{
				id="frameBackdrop", type="Image", parent="frame", layer=6,
				attach = 
				{ 
					{ point="TOPLEFT", element="frame", targetPoint="TOPLEFT" },
					{ point="BOTTOMRIGHT", element="frame", targetPoint="BOTTOMRIGHT" } 
				}, 				
				visibilityBinding="id", texAddon = AddonId, texFile = "img/Ckau_orb_back2.tga"		
			}, 
			{
				id="Red", type="Bar", parent="frame", layer=10, alpha=1,
				attach = 
				{ 
					{ point="BOTTOMRIGHT", element="frame", targetPoint="BOTTOMRIGHT" } 
				}, visibilityBinding="id", binding="healthPercent", growthDirection="up",
				texAddon=AddonId, texFile="img/Ckau_orb_red.png", 
				height=healthOrbHeight, width=healthOrbWidth,		
			},
			{
				id="gloss", type="Image", parent="frame", layer=14,
				attach = 
				{ 
					{ point="TOPLEFT", element="frame", targetPoint="TOPLEFT" },
					{ point="BOTTOMRIGHT", element="frame", targetPoint="BOTTOMRIGHT" } 
				}, visibilityBinding="id", texAddon = AddonId, texFile = "img/Ckau_orb_gloss.tga"		
			}, 			
			{
				id="health", type="Label", parent="frame", layer=19,
				attach = 
				{ 
					{ point="CENTER", element="frame", targetPoint="CENTER", offsetX=0, offsetY=-5 },
				}, visibilityBinding="id", text="{health}",fontSize=24,font="RomicCyr",outline=true,	
			}, 
			{
				id="healthPercent", type="Label", parent="frame", layer=18,
				attach = 
				{ 
					{ point="TOPCENTER", element="health", targetPoint="BOTTOMCENTER", offsetX=3, offsetY=0 },
				}, visibilityBinding="id", text="{healthPercent}%",font="RomicCyr",fontSize=16,	outline=true,	
			}, 
			{
				id="barAbsorb", type="Bar", parent="frame", layer=17,
				attach = {
					{ point="TOPLEFT", element="frameBackdrop", targetPoint="TOPCENTER", },
					{ point="BOTTOMRIGHT", element="frameBackdrop", targetPoint="BOTTOMRIGHT", },
				},
				growthDirection="left",
				binding="absorbPercent", 
				texAddon=AddonId, texFile="img/textures/Ckau_orb_absorb_glow.png", alpha=1,
				backgroundColor={r=0, g=0, b=0, a=0},
			},
			{
				-- Generic Element Configuration
				id="barCleanse", type="Bar", parent="frame", layer=40, alpha=.6,
				attach = {
					{ point="TOPLEFT", element="Red", targetPoint="TOPLEFT" },
					{ point="BOTTOMRIGHT", element="Red", targetPoint="BOTTOMRIGHT" },
				},
				visibilityBinding="CkaucleanseBar",
				growthDirection="right",
				-- Type Specific Element Configuration
				binding="health",
				texAddon=AddonId, texFile="img/textures/Ckau_orb_debuff_glow.png", alpha=.9,
				backgroundColor={r=0, g=0, b=0, a=0},
			},
		}
	}
	
	for idx,element in ipairs(template.elements) do
		self:CreateElement(element) 
	end
	
	self:SetSecureMode("restricted")
	self:SetMouseoverUnit(self.UnitSpec)
	self:EventMacroSet(Event.UI.Input.Mouse.Left.Click, "target @" .. self.UnitSpec)
	self:EventAttach(Event.UI.Input.Mouse.Right.Click, function(self, h)
		if self.UnitId then Command.Unit.Menu(self.UnitId) end
	end, "Event.UI.Input.Mouse.Right.Click")
	
end
