local toc, data = ...
local AddonId = toc.identifier

------------------------------------------------------------------------------------------------------------
-- Local config options 
------------------------------------------------------------------------------------------------------------
local CkauTargetFrameWidth = 256
local CkauTargetFrameHeight = 60
------------------------------------------------------------------------------------------------------------
-- Frame Configuration Options 
------------------------------------------------------------------------------------------------------------
local CkauTargetFrame = WT.UnitFrame:Template("CkauTargetFrames")
CkauTargetFrame.Configuration.Name = "d3 Target / Цель"
CkauTargetFrame.Configuration.RaidSuitable = False
CkauTargetFrame.Configuration.FrameType = "Frame"
CkauTargetFrame.Configuration.Width = CkauTargetFrameWidth 
CkauTargetFrame.Configuration.Height = CkauTargetFrameHeight

if WT.UnitFrame.EnableResizableTemplate then
      CkauTargetFrame.Configuration.Resizable = { CkauTargetFrameWidth * 0.50, CkauTargetFrameHeight * 0.50, CkauTargetFrameWidth * 1.5, CkauTargetFrameHeight * 1.5 }
end

------------------------------------------------------------------------------------------------------------
-- Override the buff filter to hide some buffs
------------------------------------------------------------------------------------------------------------
local buffPriorities = 
{
	["Touched by Greed"] = 0,
	["Track Wood"] = 0,
	["Track Ore"] = 0,
	["Track Plants"] = 0,
	["Track Fish"] = 0,
	["Rested"] = 0,
	["Prismatic Glory"] = 0,
	["Looking for Group Cooldown"] = 0,
	["Feast of Domination"] = 0,
	["Feast of Vengeance"] = 0,
	["Poisonous Coating"] = 0,
	["Remarkable Whetstone"] = 0,
	["Luminescent Powerstone"] = 0,
	["Comfortable Riding Chaps"] = 0,
	["Comfortable Insoles"] = 0,
	["Quantum Sight"] = 0,
	["Planar Protection"] = 0,
	["Stellar Brightsurge Vial"] = 0,
	["Stellar Powersurge Vial"] = 0,
	["Stellar Enduring Vial"] = 0,
	["Stellar Fortified Vial"] = 0,
	["Summon Banner of Rage"] = 0,
	["Summon Banner of Concentration"] = 0,
	["Summon Banner of Fortitude"] = 0,
	["Summon Banner of Protection"] = 0,
	["Fanfare of Vigor"] = 0,
	["Fanfare of Power"] = 0,
	["Ascended Courage"] = 0,
	["Planar Protection"] = 0,
	["Heroic Resolve"] = 0,
	["Empowerment: Mounted Swiftness"] = 0,
	["Empowerment: Offense"] = 0,
	["Empowerment: Healing"] = 0,
	["Thick Armor Plating"] = 0,
	[""] = 0,
	[""] = 0,
	[""] = 0,
	[""] = 0,
	[""] = 0,
	[""] = 0,
	[""] = 0,
	[""] = 0,
	[""] = 0,
	[""] = 0,
	[""] = 0,
	[""] = 0,
	[""] = 0,
	[""] = 0,
	[""] = 0,
	[""] = 0,
	[""] = 0,
	
}
function CkauTargetFrame:GetBuffPriority(buff)
	if not buff then return 2 end
	return buffPriorities[buff.name] or 2
end

------------------------------------------------------------------------------------------------------------
--
------------------------------------------------------------------------------------------------------------
function CkauTargetFrame:Construct(options)

	local template =
	{
		elements = 
		{
			{
				id="frameBackdrop", type="MediaSet", parent="frame", layer=0, alpha=1,
				attach = 
				{ 
					{ point="TOPLEFT", element="frame", targetPoint="TOPLEFT" },
					{ point="BOTTOMRIGHT", element="frame", targetPoint="BOTTOMRIGHT" }, 
				},
				visibilityBinding="CkautargetBackdropIdElite", 
				nameBinding="CkautargetBackdropIdElite",
				names = 
				{
					["CkautargetEliteBackdrop"] = "CkautargetEliteBackdrop",
					["CkautargetBackdrop"] = "CkautargetBackdrop",
				},
			},
			
			{
				id="bossBorder", type="Image", parent="frame", layer=100, alpha=1,
				attach = {{ point="CENTER", element="frameBackdrop", targetPoint="CENTER", offsetX=0, offsetY=24 }},
				width = 128, height = 64,
				visibilityBinding="CkauidBoss", 
				texAddon=AddonId, texFile="img/borders/CkautargetBossBorder.png", alpha=1, 
				backgroundColor={r=0, g=0, b=0, a=0},
			},
			{
				id="eliteBorder", type="Image", parent="frame", layer=100, alpha=1,
				attach = {{ point="CENTER", element="frameBackdrop", targetPoint="CENTER", offsetX=0, offsetY=24 }},
				width = 128, height = 64,
				visibilityBinding="CkauidElite", 
				texAddon=AddonId, texFile="img/borders/CkautargetEliteBorder.png", alpha=1, 
				backgroundColor={r=0, g=0, b=0, a=0},
			},
					
			{
				id="barResource", type="Bar", parent="frame", layer=15, alpha=.8,
				attach = 
				{
					{ point="TOPLEFT", element="frameBackdrop", targetPoint="TOPLEFT", offsetX=24.4, offsetY=39.100 },
					{ point="BOTTOMRIGHT", element="frameBackdrop", targetPoint={.905, .760} },
				},
				visibilityBinding="id",
				growthDirection="right",
				binding="resourcePercent", colorBinding="resourceColor",
				texAddon=AddonId, texFile="img/textures/CkauBlackBar.png", alpha=.4,
				backgroundColor={r=0, g=0, b=0, a=1}
			},
			{
				id="barHealth", type="Bar", parent="frame", layer=15, alpha=.8,
				attach = 
				{
					{ point="TOPLEFT", element="frameBackdrop", targetPoint="TOPLEFT", offsetX=24.4, offsetY=11.8 },
					{ point="BOTTOMRIGHT", element="frameBackdrop", targetPoint={.905, .590} },
				},
				visibilityBinding="id",
				growthDirection="right",
				binding="healthPercent", colorBinding="callingColor", 
				texAddon=AddonId, texFile="img/textures/CkauBlackBar.png", alpha=.4,
				backgroundColor={r=0, g=0, b=0, a=1},
			},
			{
				id="healthCap", type="HealthCap", parent="barHealth", layer=15,
				attach = {
					{ point="TOPLEFT", element="barHealth", targetPoint="TOPLEFT" },
					{ point="BOTTOMRIGHT", element="barHealth", targetPoint="BOTTOMRIGHT" },
				},
				growthDirection="left",
				visibilityBinding="healthCap",
				binding="healthCapPercent",					
				texAddon=AddonId, texFile="img/textures/CkauBlackBarH.png", alpha=1,
			},
			{
				id="barAbsorb", type="Bar", parent="frame", layer=41,
				attach = 
				{
					{ point="TOPLEFT", element="frameBackdrop", targetPoint="TOPLEFT", offsetX=24.4, offsetY=11.8 },
					{ point="BOTTOMRIGHT", element="frameBackdrop", targetPoint={.905, .590} },
				},
				growthDirection="right", 
				binding="absorbPercent",
				texAddon=AddonId, texFile="img/textures/CkauAbsorb.png", alpha=1,
				backgroundColor={r=0, g=0, b=0, a=0},
			},
			{
				id="imgRole", type="MediaSet", parent="frame", layer=180, alpha=1,
				attach = {{ point="CENTER", element="frameBackdrop", targetPoint="BOTTOMLEFT", offsetX=1, offsetY=-16 }},
				width = 18, height = 18,
				visibilityBinding="role",
				nameBinding="role", 
				names = { ["tank"] = "CkauRaidTank", ["heal"] = "CkauRaidHeal", ["dps"] = "CkauRaidDPS", ["support"] = "CkauRaidSupport" },
			},
			
			{
				id="imgPVP", type="MediaSet", parent="frame", layer=100, width=22, height=22,
			attach = {{ point="CENTER", element="frameBackdrop", targetPoint="BOTTOMRIGHT", offsetX=-6, offsetY=-5 }},
				nameBinding="CkaupvpFaction",
				names = 
				{
					
				},
			},
			{
				id="imgConquest", type="MediaSet", parent="frame", layer=100, width=22, height=22,
			attach = {{ point="CENTERRIGHT", element="imgPVP", targetPoint="CENTERLEFT", offsetX=25, offsetY=-15 }},
				nameBinding="CkauFaction",
				names = 
				{
					["nightfall"] = "CkaufactionNightfall",
					["oathsworn"] = "CkaufactionOathsworn",
					["dominion"] = "CkaufactionDominion",
				},
			},
			{
				id="labelNameSecondary", type="Label", parent="frame", layer=200, alpha=1,
				attach = {{ point="BOTTOMCENTER", element="barHealth", targetPoint="TOPCENTER", offsetX=2, offsetY=-1 }},
				visibilityBinding="CkausubName",
				text="<{CkausubName}>", default="", color={r=1,g=1,b=1,a=1}, font="RomicCyr", fontSize=13
			},
			{
				id="labelName", type="Label", parent="frame", layer=200, alpha=1,
				attach = {{ point="BOTTOMCENTER", element="labelNameSecondary", targetPoint="TOPCENTER", offsetX=0, offsetY=4 }},
				visibilityBinding="name",
				text="{CkaunameMed}", default="", color={r=1,g=1,b=1,a=1}, font="RomicCyr", fontSize=15, outline=true,
			},
			{
				id="imgMark", type="MediaSet", parent="frame", layer=180,
				attach = {{ point="CENTER", element="frameBackdrop", targetPoint="TOPLEFT", offsetX=16, offsetY=28 }},
				width = 20, height = 20,
				nameBinding="mark",
				names = 
				{
						["1"] = "riftMark01",
						["2"] = "riftMark02",
						["3"] = "riftMark03",
						["4"] = "riftMark04",
						["5"] = "riftMark05",
						["6"] = "riftMark06",
						["7"] = "riftMark07",
						["8"] = "riftMark08",
						["9"] = "riftMark09",
						["10"] = "riftMark10",
						["11"] = "riftMark11",
						["12"] = "riftMark12",
						["13"] = "riftMark13",
						["14"] = "riftMark14",
						["15"] = "riftMark15",
						["16"] = "riftMark16",
						["17"] = "riftMark17",
						["18"] = "riftMark18",
						["19"] = "riftMark19",
						["20"] = "riftMark20",
						["21"] = "riftMark21",
						["22"] = "riftMark22",
						["23"] = "riftMark23",
						["24"] = "riftMark24",
						["25"] = "riftMark25",
						["26"] = "riftMark26",
						["27"] = "riftMark27",
						["28"] = "riftMark28",
						["29"] = "riftMark29",
						["30"] = "riftMark30",
				},
				visibilityBinding="mark",alpha=1.0,
			},
			{
			    id="imgMark2", type="MediaSet", parent="frameBackdrop", layer=31,
			    attach = {{ point="CENTER", element="imgMark", targetPoint="CENTER", offsetX=0, offsetY=0  }},
			    width = 20, height = 20,
			    nameBinding="mark",
			    names = 
			    {
			        ["19"] = "riftMark02",
			        ["20"] = "riftMark03",
			        ["21"] = "riftMark04",
			        ["27"] = "riftMark02",
					["28"] = "riftMark03",
			        ["29"] = "riftMark04",
			    },
			    visibilityBinding="mark",alpha=1.0,
			},
			{
				id="labelRange", type="Label", parent="frame", layer=200, alpha=1,
				attach = {{ point="TOPRIGHT", element="frameBackdrop", targetPoint="TOPRIGHT", offsetX=20, offsetY=6.5 }},
				visibilityBinding="CkaurangeDisplay",
				text="{range} m", default="", colorBinding="CkaurangeColor", font="RomicCyr", fontSize=12, outline=true,
			},
			{
				id="tfHealthLabel", type="Label", parent="frame", layer=200, alpha=1,
				attach = {{ point="CENTERRIGHT", element="barHealth", targetPoint="CENTERRIGHT", offsetX=-8, offsetY=3 }},
				visibilityBinding="CkauhealthText",
				text="{health} / {healthPercent}%", default="", color={r=1,g=1,b=1,a=1}, font="RomicCyr", fontSize=13, outline=true, 
			},
			{
				id="tfAbsorbLabel", type="Label", parent="frame", layer=200,
				attach = {{ point="CENTERLEFT", element="barAbsorb", targetPoint="CENTERLEFT", offsetX=4, offsetY=2 }},
				visibilityBinding="id", 
				text="( {absorb} )", default="", color={r=1, g=1, b=1, a=1}, font="RomicCyr", fontSize=9, outline=true,
			},
			{
				id="tfResourceLabel", type="Label", parent="frame", layer=200, alpha=1,
				attach = {{ point="CENTERRIGHT", element="barResource", targetPoint="CENTERRIGHT", offsetX=-8, offsetY=2 }},
				visibilityBinding="CkauresourceText",
				text="{resource} / {resourcePercent}%", default="", color={r=1,g=1,b=1,a=1}, font="RomicCyr", fontSize=7, outline=true,
			},
			{
				id="CkauStatusLabel", type="Label", parent="frame", layer=200,
				attach = {{ point="CENTER", element="barHealth", targetPoint="CENTER", offsetX=0, offsetY=1 }},
				visibilityBinding="rgStatus",
				text="{rgStatus}", default="", font="RomicCyr", fontSize=12, outline=true,
			},
			{
				id="labelDetail", type="Label", parent="frame", layer=200, alpha=1,
				attach = {{ point="CENTERRIGHT", element="imgPVP", targetPoint="CENTERLEFT", offsetX=-28, offsetY=0 }},
				visibilityBinding="raceName",
				text="{callingText}", default="", color={r=1,g=1,b=1,a=1}, font="RomicCyr", fontSize=11, outline=true
			},
			{
				id="labelNPCDetail", type="Label", parent="frame", layer=200, alpha=1,
				attach = {{ point="CENTERRIGHT", element="imgPVP", targetPoint="CENTERLEFT", offsetX=-28, offsetY=0 }},
				visibilityBinding="tag",
				text="{tagName}", default="", color={r=1,g=1,b=1,a=1}, font="RomicCyr", fontSize=11, outline=true
			},
			{
				id="imgRare", type="Image", parent="frame", layer=60,
				attach = {{ point="CENTER", element="frameBackdrop", targetPoint="TOPCENTER", offsetX=0, offsetY=0 }},
				texAddon=AddonId, texFile="img/icons/CkaublueDiamond.png",
				visibilityBinding="guaranteedLoot",
				width=40, height=40,
			},	
			{
				id="imgLevel", type="MediaSet", parent="frame", layer=130, alpha=1,
				attach = {{ point="CENTER", element="frameBackdrop", targetPoint="TOPLEFT", offsetX=4, offsetY=10 }},
				width=32, height=32,
				visibilityBinding="CkaulevelBorder",
				nameBinding="CkaulevelBorder",
				names =
				{
						["CkaueliteIcon"] = "CkaueliteIcon",
						["CkaunormalIcon"] = "CkaunormalIcon",
				},
			},
			{
				id="imgMentor", type="Image", parent="frame", layer=140, width=30, height=30,
				attach = {{  point="BOTTOMLEFT", element="barHealth", targetPoint="BOTTOMLEFT", offsetX=-37, offsetY=-10 }},
				visibilityBinding="mentoring",
				texAddon=AddonId, texFile="img/Ckaumentor.png",
			},
			{
				id="imgLevelBoss", type="Image", parent="frame", layer=140,
				attach = {{ point="CENTER", element="imgLevel", targetPoint="CENTER", offsetX=0, offsetY=0 }},
				texAddon=AddonId, texFile="img/icons/CkaubossIcon.png", alpha=1,
				visibilityBinding="CkauidBoss",
				width=44, height=44,
			},
			{
				id="levelLabel", type="Label", parent="frame", layer=150,
				attach = {{ point="CENTER", element="imgLevel", targetPoint="CENTER", offsetX=0, offsetY=3 }},
				visibilityBinding="CkaulevelText",
				colorBinding="CkaudifficultyColor", 
				text="{level}", default="", font="RomicCyr", fontSize=13, outline=true,
			},				
			{
				id="imgLevelUnknown", type="Image", parent="frame", layer=160,
				attach = {{ point="CENTER", element="imgLevel", targetPoint="CENTER", offsetX=0, offsetY=0 }},
				texAddon=AddonId, texFile="img/icons/CkaulevelUnknown.png",
				visibilityBinding="CkaulevelUnknown",
				width=32, height=32,
			},
			{
				id="barCast", type="Bar", parent="frame", layer=90, alpha=1,
				attach = {
					{ point="TOPLEFT", element="barResource", targetPoint="TOPLEFT" },
					{ point="BOTTOMRIGHT", element="barResource", targetPoint="BOTTOMRIGHT" },
				},
				visibilityBinding="castName",
				binding="castPercent",
				texAddon=AddonId, texFile="img/textures/Ckaugloss.png", alpha=.6,
				colorBinding="castColor",
				backgroundColor={r=0, g=0, b=0, a=1}
			},
			{
				id="labelCast", type="Label", parent="frame", layer=100,
				attach = {{ point="CENTER", element="barCast", targetPoint="CENTER", offsetX=0, offsetY=1 }},
				visibilityBinding="castName",
				text="{castName}", default="", color={r=1,g=1,b=1,a=1}, font="RomicCyr",  fontSize=10, outline=true,
			},
			{
				-- Generic Element Configuration
				id="buffPanelDebuffs", type="BuffPanel", parent="frame", layer=60,
				attach = {{ point="BOTTOMRIGHT", element="barHealth", targetPoint="BOTTOMRIGHT", }},
				-- Type Specific Element Configuration
				rows=1, cols=3, iconSize=14, iconSpacing=.75, borderThickness=.5, 
				acceptLowPriorityBuffs=false, acceptMediumPriorityBuffs=false, acceptHighPriorityBuffs=false, acceptCriticalPriorityBuffs=false,
				acceptLowPriorityDebuffs=false, acceptMediumPriorityDebuffs=true, acceptHighPriorityDebuffs=true, acceptCriticalPriorityDebuffs=true,
				growthDirection = "left_up", sweepOverlay=false,
			},
			
			{
				id="aggroBorder", type="Image", parent="frame", layer=2, alpha=1,
				attach = 
				{ 
					{ point="TOPLEFT", element="frame", targetPoint="TOPLEFT", offsetX=-0, offsetY=-18 },
					{ point="BOTTOMRIGHT", element="frame", targetPoint="BOTTOMRIGHT", offsetX=0, offsetY=18 }, 
				}, 				
				visibilityBinding="CkauunitAggro",
				texAddon = AddonId, texFile = "img/borders/CkauaggroBorder.png", alpha=1,
				backgroundColor={r=0, g=0, b=0, a=0},
			},
			{
				id="frameBlocked", type="Image", parent="frame", layer=100, alpha=1,				
				attach = 
				{ 
					{ point="TOPLEFT", element="frame", targetPoint="TOPLEFT", offsetX=-0, offsetY=-18 },
					{ point="BOTTOMRIGHT", element="frame", targetPoint="BOTTOMRIGHT", offsetX=0, offsetY=18 },  
				},
				visibilityBinding="blockedOrOutOfRange",			
				texAddon=AddonId, texFile="img/textures/CkauBlockedFrame.png", alpha=1,
				backgroundColor={r=0, g=0, b=0, a=0},			
			}, 
			{
				-- Generic Element Configuration
				id="barCleanse", type="Bar", parent="frame", layer=40, alpha=.6,
				attach = {
					{ point="TOPLEFT", element="barHealth", targetPoint="TOPLEFT", },
					{ point="BOTTOMRIGHT", element="barHealth", targetPoint="BOTTOMRIGHT" },
				},
				visibilityBinding="CkaucleanseBar",
				growthDirection="right",
				-- Type Specific Element Configuration
				binding="healthPercent",
				texAddon=AddonId, texFile="img/textures/CkauBarCleanse.png", alpha=.9,
				backgroundColor={r=0, g=0, b=0, a=0},
			},
		}
	}
	
	if WT.UnitFrame.EnableResizableTemplate then
            WT.UnitFrame.EnableResizableTemplate(self, CkauTargetFrameWidth, CkauTargetFrameHeight, template.elements)
    end
	
	local animations =
		{
            {
				-- Aggro Warning Animation
                trigger = "CkauaggroWarning",
                duration = .80,
                loopCount = 0,
                onStart =
					function(elements)
						elements.aggroBorder:SetAlpha(.5)
                        end,
					onTick =
                        function(elements, elapsed, progress)
                            elements.aggroBorder:SetAlpha((math.sin(progress * (2.0 * math.pi)) + 1.5) / 3.0)
                        end,             
					onFinish =
                        function(elements)
                            elements.aggroBorder:SetAlpha(1.0)
                        end,             
            },
      }
     
      if WT.UnitFrame.EnableAnimation then
            WT.UnitFrame.EnableAnimation(self, animations)
      end
	
	
	
	
	for idx,element in ipairs(template.elements) do
		local showElement = true
		if options.excludeBuffs and element.type=="BuffPanel" then showElement = false end
		if options.excludeCasts and ((element.id == "barCast") or (element.id == "labelCast")) then showElement = false end
		if not options.showAbsorb and (element.id=="barAbsorb" or element.id=="labelHealthAndAbsorbPercent") then 
			showElement = false 
		end
		if showElement then
			self:CreateElement(element)
		end 
	end
	
	local elSecondary = self.Elements.labelNameSecondary
	local origFn = elSecondary.SetText
	function elSecondary:SetText(txt)
		origFn(elSecondary, txt)
		if txt == "" then
            elSecondary:SetHeight(0)
		else
            elSecondary:ClearHeight()
		end
	end
	
	--[[
	self:CreateBinding("calling", self, 		
		function(frame, newCalling)	
			local img = self.Elements.barResource.Image
			if not newCalling then return end
			if newCalling == "warrior" then img:SetTexture(AddonId, "img/textures/warriorNeon.png") end
			if newCalling == "rogue" then img:SetTexture(AddonId, "img/textures/rogueNeon.png") end
			if newCalling == "mage" then img:SetTexture(AddonId, "img/textures/mageNeon.png") end		
			if newCalling == "cleric" then img:SetTexture(AddonId, "img/textures/clericNeon.png") end	
	end	)
	--]]
	
	self:SetSecureMode("restricted")
	self:SetMouseoverUnit(self.UnitSpec)
	self.Event.LeftClick = "target @" .. self.UnitSpec
	self.Event.RightClick = function() if self.UnitId then Command.Unit.Menu(self.UnitId) end end
end


