local toc, data = ...
local AddonId = toc.identifier
-- Local config options ---------------------------------------------------------
local CkauRaidFrameWidth = 148
local CkauRaidFrameHeight = 80

---------------------------------------------------------------------------------

-- Frame Configuration Options --------------------------------------------------
local CkauRaidFrame = WT.UnitFrame:Template("CkauTargetTargetFrame")
CkauRaidFrame.Configuration.Name = "d3 Target of Target / Цель Цели"
CkauRaidFrame.Configuration.RaidSuitable = true
CkauRaidFrame.Configuration.FrameType = "Frame"
CkauRaidFrame.Configuration.Width = CkauRaidFrameWidth
CkauRaidFrame.Configuration.Height = CkauRaidFrameHeight

-- Only enable resizing if the installed version of Gadgets can handle it:
if WT.UnitFrame.EnableResizableTemplate then
      CkauRaidFrame.Configuration.Resizable = { CkauRaidFrameWidth * 0.75, CkauRaidFrameHeight * 0.75, CkauRaidFrameWidth * 2.0, CkauRaidFrameHeight * 2.0 }
end
---------------------------------------------------------------------------------

function CkauRaidFrame:Construct(options)

	local template =
	{
		elements = 
		{
			{
				id="frameBackdrop", type="Image", parent="frame", layer=0, alpha=1,
				attach = 
				{ 
					{ point="TOPLEFT", element="frame", targetPoint="TOPLEFT", offsetX=.5, offsetY=.5 },
					{ point="BOTTOMRIGHT", element="frame", targetPoint="BOTTOMRIGHT", offsetX=-.5, offsetY=-.5 },
				},
				visibilityBinding="id", 
				-- Type Specific Element Configuration
				texAddon=AddonId, texFile="img/borders/CkauraidBackdrop.png", alpha=1, 
				backgroundColor={r=0, g=0, b=0, a=0},
			},			
			
			{
				id="barHealth", type="Bar", parent="frame", layer=30, alpha=.8,
				attach = 
				{
					{ point="TOPLEFT", element="frameBackdrop", targetPoint="TOPLEFT", offsetX=28.5, offsetY=27 },
					{ point="BOTTOMRIGHT", element="frameBackdrop", targetPoint="BOTTOMRIGHT", offsetX=-28.5, offsetY=-35.5 },
				},
				visibilityBinding="CkauRaidCleanse",
				growthDirection="right",
				binding="healthPercent", colorBinding="callingColor",
				texAddon=AddonId, texFile="img/textures/CkauBlackBar.png", alpha=.4,
				backgroundColor={r=0, g=0, b=0, a=1},
			},
			{
				id="healthCap", type="HealthCap", parent="barHealth", layer=15,
				attach = {
					{ point="TOPLEFT", element="barHealth", targetPoint="TOPLEFT" },
					{ point="BOTTOMRIGHT", element="barHealth", targetPoint="BOTTOMRIGHT" },
				},
				growthDirection="left",
				visibilityBinding="healthCap",
				binding="healthCapPercent",				
				texAddon=AddonId, texFile="img/textures/CkauBlackBarH.png", alpha=1,
			},
			{
				id="tfHealthLabel", type="Label", parent="frame", layer=200, alpha=1,
				attach = {{ point="CENTERRIGHT", element="barHealth", targetPoint="CENTERRIGHT", offsetX=-8, offsetY=3 }},
				visibilityBinding="CkauhealthText",
				text="{healthPercent}%", default="", color={r=1,g=1,b=1,a=1}, font="RomicCyr", fontSize=12, outline=true, 
			},
			{
				-- Generic Element Configuration
				id="barCleanse", type="Bar", parent="frame", layer=40, alpha=.6,
				attach = {
					{ point="TOPLEFT", element="barHealth", targetPoint="TOPLEFT", },
					{ point="BOTTOMRIGHT", element="barHealth", targetPoint="BOTTOMRIGHT" },
				},
				visibilityBinding="CkaucleanseBar",
				growthDirection="right",
				-- Type Specific Element Configuration
				binding="healthPercent",
				texAddon=AddonId, texFile="img/textures/CkauBarCleanse.png", alpha=.9,
				backgroundColor={r=0, g=0, b=0, a=0},
			},
			{
				id="barResource", type="Bar", parent="frame", layer=15, alpha=.8,
				attach = 
				{
					{ point="TOPLEFT", element="frameBackdrop", targetPoint="TOPLEFT", offsetX=28.5, offsetY=47 },
					{ point="BOTTOMRIGHT", element="frameBackdrop", targetPoint="BOTTOMRIGHT", offsetX=-28.5, offsetY=-27.5 },
				},
				visibilityBinding="id",
				growthDirection="right",
				binding="resourcePercent", colorBinding="resourceColor",
				texAddon=AddonId, texFile="img/textures/CkauBlackBar.png", alpha=.4,
				backgroundColor={r=0, g=0, b=0, a=1}
			},
			{
				id="barAbsorb", type="Bar", parent="frame", layer=50,
				attach = {
					{ point="TOPLEFT", element="frameBackdrop", targetPoint="TOPLEFT", offsetX=28.5, offsetY=27 },
					{ point="BOTTOMRIGHT", element="frameBackdrop", targetPoint="BOTTOMRIGHT", offsetX=-28.5, offsetY=-35.5 },
				},
				growthDirection="right",
				binding="absorbPercent", 
				texAddon=AddonId, texFile="img/textures/CkauAbsorb.png", alpha=1,
				backgroundColor={r=0, g=0, b=0, a=0},
			},
			{
				-- Generic Element Configuration
				id="labelName", type="Label", parent="frame", layer=150, alpha=1,
				attach = {{ point="BOTTOMCENTER", element="barHealth", targetPoint="TOPCENTER", offsetX=-2, offsetY=0 }},
				visibilityBinding="name",
				-- Type Specific Element Configuration
				text="{CkaunameMini}", default="", color={r=1,g=1,b=1,a=1}, font="RomicCyr", fontSize=15, outline=true, 
			},			
			{
				-- Generic Element Configuration
				id="frameRole", type="Frame", parent="frame", layer=40, alpha=1,
				attach = {{ point="BOTTOMLEFT", element="barHealth", targetPoint="TOPLEFT", offsetX=-25, offsetY=6.5 }}, 
				width = 14, height = 14,
				color={r=0,g=0,b=0,a=0}, 
			},
			{
				id="imgRole", type="MediaSet", parent="frame", layer=80,
				attach = {{ point="CENTER", element="frameRole", targetPoint="CENTER" }},
				width = 13, height = 13,
				visibilityBinding="role",
				nameBinding="role", 
				names = { ["tank"] = "CkauRaidTank", ["heal"] = "CkauRaidHeal", ["dps"] = "CkauRaidDPS", ["support"] = "CkauRaidSupport" },
			},
			{
				-- Generic Element Configuration
				id="frameCharges", type="Frame", parent="frame", layer=40, alpha=1,
				attach = {{ point="TOPRIGHT", element="imgRole", targetPoint="BOTTOMRIGHT", offsetX=-2, offsetY=0 }},
				width = 10, height = 10,
				color={r=0,g=0,b=0,a=0}, 
			},
			{
				-- Generic Element Configuration
				id="chargeLabel", type="Label", parent="frame", layer=80,
				attach = {{ point="CENTER", element="frameCharges", targetPoint="CENTER", offsetX=0, offsetY=0 }},
				text="", color={r=0,g=1,b=1,a=1}, font="RomicCyr", fontSize=9,
			},
			
			{
				-- Generic Element Configuration
				id="labelStatus", type="Label", parent="frame", layer=150,
				attach = {{ point="CENTER", element="barHealth", targetPoint="CENTER", offsetX=-2, offsetY=3 }},
				visibilityBinding="rgStatus",
				text="{rgStatus}", default="", font="RomicCyr", fontSize=12, outline=true,
			},
			{
			    id="imgMark", type="MediaSet", parent="frame", layer=60,
			    attach = {{ point="CENTERLEFT", element="barHealth", targetPoint="CENTERLEFT", offsetX=2.5, offsetY=1 }},
			    width = 16, height = 16,
			    nameBinding="mark",
			    names = 
			    {
			        ["1"] = "riftMark01_mini",
			        ["2"] = "riftMark02_mini",
			        ["3"] = "riftMark03_mini",
			        ["4"] = "riftMark04_mini",
			        ["5"] = "riftMark05_mini",
			        ["6"] = "riftMark06_mini",
			        ["7"] = "riftMark07_mini",
			        ["8"] = "riftMark08_mini",
			        ["9"] = "riftMark09_mini",
			        ["10"] = "riftMark10_mini",
			        ["11"] = "riftMark11_mini",
			        ["12"] = "riftMark12_mini",
			        ["13"] = "riftMark13_mini",
			        ["14"] = "riftMark14_mini",
			        ["15"] = "riftMark15_mini",
			        ["16"] = "riftMark16_mini",
			        ["17"] = "riftMark17_mini",
					["18"] = "riftMark18_mini",
					["19"] = "riftMark19_mini",
					["20"] = "riftMark20_mini",
					["21"] = "riftMark21_mini",
					["22"] = "riftMark22_mini",
					["23"] = "riftMark23_mini",
					["24"] = "riftMark24_mini",
					["25"] = "riftMark25_mini",
					["26"] = "riftMark26_mini",
					["27"] = "riftMark27_mini",
					["28"] = "riftMark28_mini",
					["29"] = "riftMark29_mini",
					["30"] = "riftMark30_mini",
			    },
			    visibilityBinding="mark", alpha=1.0,
			},
			{
			    id="imgMark2", type="MediaSet", parent="frame", layer=31,
			    attach = {{ point="CENTER", element="imgMark", targetPoint="CENTER", offsetX=0, offsetY=0  }},
			    width = 16, height = 16,
			    nameBinding="mark",
			    names = 
			    {
			        ["19"] = "riftMark02_mini",
			        ["20"] = "riftMark03_mini",
			        ["21"] = "riftMark04_mini",
			        ["27"] = "riftMark02_mini",
					["28"] = "riftMark03_mini",
			        ["29"] = "riftMark04_mini",
			    },
			    visibilityBinding="mark",alpha=1.0,
			},
			{
				-- Generic Element Configuration
				id="imgReady", type="ImageSet", parent="frame", layer=50,
				attach = {{ point="CENTERLEFT", element="barHealth", targetPoint="CENTERLEFT", offsetX=14.5, offsetY=1 }}, 
				 width = 20, height = 20,
				 visibilityBinding="readyStatus",
				-- Type Specific Element Configuration
				texAddon=AddonId, texFile="img/icons/CkauncReady.png", nameBinding="readyStatus", cols=1, rows=2, 
				names = { ["ready"] = 0, ["notready"] = 1 }, defaultIndex = "hide"
			},
			{
				id="frameBlocked", type="Image", parent="frame", layer=100, alpha=1,				
				attach = 
				{ 
					{ point="TOPLEFT", element="frame", targetPoint="TOPLEFT", offsetX=.5, offsetY=.5, },
					{ point="BOTTOMRIGHT", element="frame", targetPoint="BOTTOMRIGHT", offsetX=-.5, offsetY=-.5, }  
				},
				visibilityBinding="blockedOrOutOfRange",			
				texAddon=AddonId, texFile="img/textures/CkauBlockedRaidFrame.png", alpha=1,
				backgroundColor={r=0, g=0, b=0, a=0},			
			}, 			
		}
	}
	
	if WT.UnitFrame.EnableResizableTemplate then
            WT.UnitFrame.EnableResizableTemplate(self, CkauRaidFrameWidth, CkauRaidFrameHeight, template.elements)
    end
	
	local animations =
		{
            
        }
     
      if WT.UnitFrame.EnableAnimation then
            WT.UnitFrame.EnableAnimation(self, animations)
      end
	
	for idx,element in ipairs(template.elements) do
		if not options.showAbsorb and element.id == "barAbsorb" then 
			-- showElement = false
		else 
			self:CreateElement(element)
		end
	end
	
	
	--[[
	self:CreateBinding("calling", self, 		
		function(frame, newCalling)	
			local img = self.Elements.barHealth.Image
			if not newCalling then return end
			if newCalling == "warrior" then img:SetTexture(AddonId, "img/textures/darkWarrior.png") end
			if newCalling == "rogue" then img:SetTexture(AddonId, "img/textures/darkRogue.png") end
			if newCalling == "mage" then img:SetTexture(AddonId, "img/textures/darkMage.png") end		
			if newCalling == "cleric" then img:SetTexture(AddonId, "img/textures/darkCleric.png") end	
	end	)
	--]]
	self:SetSecureMode("restricted")
	self:SetMouseoverUnit(self.UnitSpec)
	self:SetMouseMasking("limited")
	if options.clickToTarget then
		self.Event.LeftClick = "target @" .. self.UnitSpec
	end
	if options.contextMenu then
		self.Event.RightClick = function() if self.UnitId then Command.Unit.Menu(self.UnitId) end end
	end

end

